@@ -81,6 +81,14 @@ class Export(QDialog):
         self.buttonBox.addButton(QPushButton(_('Cancel')), QDialogButtonBox.RejectRole)
         self.exporting = False
 
+        # Update FPS / Profile timer
+        # Timer to use a delay before applying new profile/fps data (so we don't spam libopenshot)
+        self.delayed_fps_timer = None
+        self.delayed_fps_timer = QTimer()
+        self.delayed_fps_timer.setInterval(200)
+        self.delayed_fps_timer.timeout.connect(self.delayed_fps_callback)
+        self.delayed_fps_timer.stop()
+
         # Pause playback (to prevent crash since we are fixing to change the timeline's max size)
         get_app().window.actionPlay_trigger(None, force="pause")
 
@@ -247,6 +255,21 @@ class Export(QDialog):
         # Determine the length of the timeline (in frames)
         self.updateFrameRate()
 
+    def delayed_fps_callback(self):
+        """Callback for fps/profile changed event timer (to delay the timeline mapping so we don't spam libopenshot)"""
+        # Stop timer
+        self.delayed_fps_timer.stop()
+
+        # Calculate fps
+        fps_double = self.timeline.info.fps.ToDouble()
+
+        # Apply mapping if valid fps detected (anything larger than 300 fps is considered invalid)
+        if self.timeline and fps_double <= 300.0:
+            log.info("Valid framerate detected, sending to libopenshot: %s" % fps_double)
+            self.timeline.ApplyMapperToClips()
+        else:
+            log.warning("Invalid framerate detected, not sending it to libopenshot: %s" % fps_double)
+
     def getProfilePath(self, profile_name):
         """Get the profile path that matches the name"""
         for profile, path in self.profile_paths.items():
@@ -294,8 +317,8 @@ class Export(QDialog):
         self.timeline.info.channels = self.txtChannels.value()
         self.timeline.info.channel_layout = self.cboChannelLayout.currentData()
 
-        # Force ApplyMapperToClips to apply these changes
-        self.timeline.ApplyMapperToClips()
+        # Send changes to libopenshot (apply mappings to all framemappers)... after a small delay
+        self.delayed_fps_timer.start()
 
         # Determine max frame (based on clips)
         timeline_length = 0.0
@@ -372,8 +395,8 @@ class Export(QDialog):
         # Load profile settings into advanced editor
         self.txtWidth.setValue(profile.info.width)
         self.txtHeight.setValue(profile.info.height)
-        self.txtFrameRateNum.setValue(profile.info.fps.num)
         self.txtFrameRateDen.setValue(profile.info.fps.den)
+        self.txtFrameRateNum.setValue(profile.info.fps.num)
         self.txtAspectRatioNum.setValue(profile.info.display_ratio.num)
         self.txtAspectRatioDen.setValue(profile.info.display_ratio.den)
         self.txtPixelRatioNum.setValue(profile.info.pixel_ratio.num)
@@ -613,6 +636,9 @@ class Export(QDialog):
                           "audio_bitrate": int(self.convert_to_bytes(self.txtAudioBitrate.text()))
                           }
 
+        # Set MaxSize (so we don't have any downsampling)
+        self.timeline.SetMaxSize(video_settings.get("width"), video_settings.get("height"))
+
         # Set lossless cache settings (temporarily)
         export_cache_object = openshot.CacheMemory(250)
         self.timeline.SetCache(export_cache_object)
