@@ -29,6 +29,7 @@
 import os
 import glob
 import re
+import sys
 from urllib.parse import urlparse
 
 import openshot  # Python module for libopenshot (required video editing module installed separately)
@@ -81,6 +82,15 @@ class FilesListView(QListView):
         if self.selected:
             # If file selected, show file related options
             menu.addSeparator()
+
+            # Add edit title option (if svg file)
+            selected_file_id = self.win.selected_files[0]
+            file = File.get(id=selected_file_id)
+            if file.data.get("path").endswith(".svg"):
+                menu.addAction(self.win.actionEditTitle)
+                menu.addAction(self.win.actionDuplicateTitle)
+                menu.addSeparator()
+
             menu.addAction(self.win.actionPreview_File)
             menu.addAction(self.win.actionSplitClip)
             menu.addAction(self.win.actionAdd_to_Timeline)
@@ -268,8 +278,8 @@ class FilesListView(QListView):
             file_url = urlparse(uri.toString())
             if file_url.scheme == "file":
                 filepath = file_url.path
-                if filepath[0] == "/" and ":" in filepath:
-                    filepath = filepath[1:]
+                if sys.platform == "win32":
+                    filepath = filepath[1:] # Remove / at beginning of path (just for Windows)
                 if os.path.exists(filepath.encode('UTF-8')) and os.path.isfile(filepath.encode('UTF-8')):
                     log.info('Adding file: {}'.format(filepath))
                     if self.add_file(filepath):
@@ -299,7 +309,10 @@ class FilesListView(QListView):
 
     def prepare_for_delete(self):
         """Remove signal handlers and prepare for deletion"""
-        pass
+        try:
+            self.files_model.model.ModelRefreshed.disconnect()
+        except:
+            pass
 
     def __init__(self, *args):
         # Invoke parent init
@@ -319,11 +332,13 @@ class FilesListView(QListView):
         # Setup header columns
         self.setModel(self.files_model.model)
         self.setIconSize(QSize(131, 108))
+        self.setGridSize(QSize(102, 92))
         self.setViewMode(QListView.IconMode)
         self.setResizeMode(QListView.Adjust)
         self.setSelectionMode(QAbstractItemView.ExtendedSelection)
         self.setUniformItemSizes(True)
-        self.setWordWrap(True)
+        self.setWordWrap(False)
+        self.setTextElideMode(Qt.ElideRight)
         self.setStyleSheet('QListView::item { padding-top: 2px; }')
 
         # Refresh view
